@@ -18,7 +18,6 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
@@ -65,7 +64,7 @@ namespace gbrainy.Games.Calculation
 		};
 
 		public override string Name {
-			get {return Catalog.GetString ("Primes");}
+			get {return Translations.GetString ("Primes");}
 		}
 
 		public override GameTypes Type {
@@ -74,22 +73,23 @@ namespace gbrainy.Games.Calculation
 
 		public override string Question {
 			get { return String.Format (
-				Catalog.GetString ("Which of the following numbers is a prime? A prime number is a positive integer that has exactly two different positive divisors, 1 and itself. Answer {0}, {1}, {2} or {3}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
+				Translations.GetString ("Which of the following numbers is a prime? A prime number is a positive integer that has exactly two different positive divisors, 1 and itself. Answer {0}, {1}, {2} or {3}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("If the sum of all digits in a given number is divisible by 3, then so is the number. For example 15 = 1 + 5 = 6, which is divisible by 3.");}
+			get { return Translations.GetString ("If the sum of all digits in a given number is divisible by 3, then so is the number. For example 15 = 1 + 5 = 6, which is divisible by 3.");}
 		}
 
 		public override string Rationale {
 			get { 
-				return String.Format (Catalog.GetString ("The number {0} is a primer number."), answer);
+				return String.Format (Translations.GetString ("The number {0} is a primer number."), answer);
 			}
 		}
 
 		protected override void Initialize ()
 		{
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption;
 			switch (CurrentDifficulty) {
 			case GameDifficulty.Easy:
 				div3 = true;
@@ -114,7 +114,7 @@ namespace gbrainy.Games.Calculation
 			answer_idx = random.Next (numbers.Length);
 			answer = primes [random.Next (max_primeidx + 1)];
 			numbers [answer_idx] = answer;
-			right_answer = answer.ToString ();
+			Answer.SetMultiOptionAnswer (answer_idx, answer.ToString ());
 
 			// Drawing objects
 			double x = DrawAreaX + 0.25, y = DrawAreaY + 0.16;
@@ -128,7 +128,7 @@ namespace gbrainy.Games.Calculation
 				drawable_area.Y = y + i * 0.15;
 				container.AddChild (drawable_area);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
@@ -136,7 +136,7 @@ namespace gbrainy.Games.Calculation
 
 					e.Context.SetPangoLargeFontSize ();
 					e.Context.MoveTo (0.02, 0.02);
-					e.Context.ShowPangoText (String.Format ("{0}) {1:##0.###}", GetPossibleAnswer (n) , numbers [n]));
+					e.Context.ShowPangoText (String.Format ("{0}) {1:##0.###}", Answer.GetMultiOption (n) , numbers [n]));
 				};
 			}
 		}
@@ -147,8 +147,8 @@ namespace gbrainy.Games.Calculation
 
 			gr.SetPangoLargeFontSize ();
 
-			gr.MoveTo (0.05, DrawAreaY + 0.1);
-			gr.ShowPangoText (Catalog.GetString ("Numbers"));
+			gr.MoveTo (0.1, 0.15);
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
 		}
 
 		short GenerateNonPrime ()
@@ -169,16 +169,5 @@ namespace gbrainy.Games.Calculation
 			}
 			return num;
 		}
-
-		public override bool CheckAnswer (string answer)
-		{
-			if (base.CheckAnswer (answer) == true)
-				return true;
-
-			if (String.Compare (answer, GetPossibleAnswer (answer_idx), true) == 0)
-				return true;
-
-			return false;
-		}
 	}
 }
